@@ -10,7 +10,13 @@ describe 'gnocchi::db::sync' do
         :path        => '/usr/bin',
         :user        => 'gnocchi',
         :refreshonly => 'true',
-        :logoutput   => 'on_failure'
+        :try_sleep   => 5,
+        :tries       => 10,
+        :logoutput   => 'on_failure',
+        :subscribe   => ['Anchor[gnocchi::install::end]',
+                         'Anchor[gnocchi::config::end]',
+                         'Anchor[gnocchi::dbsync::begin]'],
+        :notify      => 'Anchor[gnocchi::dbsync::end]',
       )
     end
     describe "overriding extra_opts" do
@@ -24,7 +30,13 @@ describe 'gnocchi::db::sync' do
             :path        => '/usr/bin',
             :user        => 'gnocchi',
             :refreshonly => 'true',
-            :logoutput   => 'on_failure'
+            :try_sleep   => 5,
+            :tries       => 10,
+            :logoutput   => 'on_failure',
+            :subscribe   => ['Anchor[gnocchi::install::end]',
+                             'Anchor[gnocchi::config::end]',
+                             'Anchor[gnocchi::dbsync::begin]'],
+            :notify      => 'Anchor[gnocchi::dbsync::end]',
         )
        }
     end
